Readable

Trait Readable 

pub trait Readable: RegisterSpec {
    type Reader: From<R<Self>> + Deref<Target = R<Self>>;
}
Trait implemented by readable registers to enable the read method.

Registers marked with Writable can be also be modify’ed.

Required Associated Types

type Reader: From<R<Self>> + Deref<Target = R<Self>>

Result from a call to read and argument to modify.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl Readable for ADCFG2_SPEC

read() method returns adcfg2::R reader structure

Source

impl Readable for ADCFG_SPEC

read() method returns adcfg::R reader structure

Source

impl Readable for ADCHS_SPEC

read() method returns adchs::R reader structure

Source

impl Readable for ADCMPR_SPEC

read() method returns adcmpr::R reader structure

Source

impl Readable for ADCR_SPEC

read() method returns adcr::R reader structure

Source

impl Readable for ADDATA_SPEC

read() method returns addata::R reader structure

Source

impl Readable for ADDR0_SPEC

read() method returns addr0::R reader structure

Source

impl Readable for ADSTA_SPEC

read() method returns adsta::R reader structure

Source

impl Readable for ADSTA_EXT_SPEC

read() method returns adsta_ext::R reader structure

Source

impl Readable for ANY_CFG_SPEC

read() method returns any_cfg::R reader structure

Source

impl Readable for ANY_CR_SPEC

read() method returns any_cr::R reader structure

Source

impl Readable for CHANY0_SPEC

read() method returns chany0::R reader structure

Source

impl Readable for CHANY1_SPEC

read() method returns chany1::R reader structure

Source

impl Readable for JADDATA_SPEC

read() method returns jaddata::R reader structure

Source

impl Readable for JDR0_SPEC

read() method returns jdr0::R reader structure

Source

impl Readable for JOFR0_SPEC

read() method returns jofr0::R reader structure

Source

impl Readable for JSQR_SPEC

read() method returns jsqr::R reader structure

Source

impl Readable for SMPR1_SPEC

read() method returns smpr1::R reader structure

Source

impl Readable for SMPR2_SPEC

read() method returns smpr2::R reader structure

Source

impl Readable for mm32f5::bkp::cr::CR_SPEC

read() method returns cr::R reader structure

Source

impl Readable for mm32f5::bkp::csr::CSR_SPEC

read() method returns csr::R reader structure

Source

impl Readable for mm32f5::bkp::dr::DR_SPEC

read() method returns dr::R reader structure

Source

impl Readable for RTCCR_SPEC

read() method returns rtccr::R reader structure

Source

impl Readable for CRV_SPEC

read() method returns crv::R reader structure

Source

impl Readable for mm32f5::comp::csr::CSR_SPEC

read() method returns csr::R reader structure

Source

impl Readable for POLL_SPEC

read() method returns poll::R reader structure

Source

impl Readable for mm32f5::cordic::cr::CR_SPEC

read() method returns cr::R reader structure

Source

impl Readable for DXR_SPEC

read() method returns dxr::R reader structure

Source

impl Readable for DYR_SPEC

read() method returns dyr::R reader structure

Source

impl Readable for DZR_SPEC

read() method returns dzr::R reader structure

Source

impl Readable for RXR_SPEC

read() method returns rxr::R reader structure

Source

impl Readable for RYR_SPEC

read() method returns ryr::R reader structure

Source

impl Readable for RZR_SPEC

read() method returns rzr::R reader structure

Source

impl Readable for mm32f5::cordic::sr::SR_SPEC

read() method returns sr::R reader structure

Source

impl Readable for mm32f5::crc::cr::CR_SPEC

read() method returns cr::R reader structure

Source

impl Readable for mm32f5::crc::dr::DR_SPEC

read() method returns dr::R reader structure

Source

impl Readable for mm32f5::crc::idr::IDR_SPEC

read() method returns idr::R reader structure

Source

impl Readable for IVR_SPEC

read() method returns ivr::R reader structure

Source

impl Readable for mm32f5::crc::pr::PR_SPEC

read() method returns pr::R reader structure

Source

impl Readable for mm32f5::crs::cfgr::CFGR_SPEC

read() method returns cfgr::R reader structure

Source

impl Readable for mm32f5::crs::cr::CR_SPEC

read() method returns cr::R reader structure

Source

impl Readable for L_SR_SPEC

read() method returns l_sr::R reader structure

Source

impl Readable for mm32f5::dac::cr::CR_SPEC

read() method returns cr::R reader structure

Source

impl Readable for DHR8R1_SPEC

read() method returns dhr8r1::R reader structure

Source

impl Readable for DHR8R2_SPEC

read() method returns dhr8r2::R reader structure

Source

impl Readable for DHR8RD_SPEC

read() method returns dhr8rd::R reader structure

Source

impl Readable for DHR12L1_SPEC

read() method returns dhr12l1::R reader structure

Source

impl Readable for DHR12L2_SPEC

read() method returns dhr12l2::R reader structure

Source

impl Readable for DHR12LD_SPEC

read() method returns dhr12ld::R reader structure

Source

impl Readable for DHR12R1_SPEC

read() method returns dhr12r1::R reader structure

Source

impl Readable for DHR12R2_SPEC

read() method returns dhr12r2::R reader structure

Source

impl Readable for DHR12RD_SPEC

read() method returns dhr12rd::R reader structure

Source

impl Readable for DOR1_SPEC

read() method returns dor1::R reader structure

Source

impl Readable for DOR2_SPEC

read() method returns dor2::R reader structure

Source

impl Readable for mm32f5::dbgmcu::cr::CR_SPEC

read() method returns cr::R reader structure

Source

impl Readable for IDCODE_SPEC

read() method returns idcode::R reader structure

Source

impl Readable for mm32f5::dma1::ccr1::CCR1_SPEC

read() method returns ccr1::R reader structure

Source

impl Readable for CMAR1_SPEC

read() method returns cmar1::R reader structure

Source

impl Readable for CNDTR1_SPEC

read() method returns cndtr1::R reader structure

Source

impl Readable for CPAR1_SPEC

read() method returns cpar1::R reader structure

Source

impl Readable for mm32f5::dma1::isr::ISR_SPEC

read() method returns isr::R reader structure

Source

impl Readable for DMABSR_SPEC

read() method returns dmabsr::R reader structure

Source

impl Readable for DMACURRXBFAR_SPEC

read() method returns dmacurrxbfar::R reader structure

Source

impl Readable for DMACURRXDSAR_SPEC

read() method returns dmacurrxdsar::R reader structure

Source

impl Readable for DMACURTXBFAR_SPEC

read() method returns dmacurtxbfar::R reader structure

Source

impl Readable for DMACURTXDSAR_SPEC

read() method returns dmacurtxdsar::R reader structure

Source

impl Readable for DMAFLCR_SPEC

read() method returns dmaflcr::R reader structure

Source

impl Readable for DMAIR_SPEC

read() method returns dmair::R reader structure

Source

impl Readable for DMAMDR_SPEC

read() method returns dmamdr::R reader structure

Source

impl Readable for DMARXDSAR_SPEC

read() method returns dmarxdsar::R reader structure

Source

impl Readable for DMARXPDR_SPEC

read() method returns dmarxpdr::R reader structure

Source

impl Readable for DMASR_SPEC

read() method returns dmasr::R reader structure

Source

impl Readable for DMATXDSAR_SPEC

read() method returns dmatxdsar::R reader structure

Source

impl Readable for DMATXPDR_SPEC

read() method returns dmatxpdr::R reader structure

Source

impl Readable for DMAWDTR_SPEC

read() method returns dmawdtr::R reader structure

Source

impl Readable for MACAFR_SPEC

read() method returns macafr::R reader structure

Source

impl Readable for MACAHR0_SPEC

read() method returns macahr0::R reader structure

Source

impl Readable for MACALR0_SPEC

read() method returns macalr0::R reader structure

Source

impl Readable for MACCR_SPEC

read() method returns maccr::R reader structure

Source

impl Readable for MACFCR_SPEC

read() method returns macfcr::R reader structure

Source

impl Readable for MACHTHR_SPEC

read() method returns machthr::R reader structure

Source

impl Readable for MACHTLR_SPEC

read() method returns machtlr::R reader structure

Source

impl Readable for MACIMR_SPEC

read() method returns macimr::R reader structure

Source

impl Readable for MACISR_SPEC

read() method returns macisr::R reader structure

Source

impl Readable for MACSMIAR_SPEC

read() method returns macsmiar::R reader structure

Source

impl Readable for MACSMIDR_SPEC

read() method returns macsmidr::R reader structure

Source

impl Readable for MACSR_SPEC

read() method returns macsr::R reader structure

Source

impl Readable for MACVLHTR_SPEC

read() method returns macvlhtr::R reader structure

Source

impl Readable for MACVLTRR_SPEC

read() method returns macvltrr::R reader structure

Source

impl Readable for MACVLTTR_SPEC

read() method returns macvlttr::R reader structure

Source

impl Readable for MMCCR_SPEC

read() method returns mmccr::R reader structure

Source

impl Readable for MMCRALIER_SPEC

read() method returns mmcralier::R reader structure

Source

impl Readable for MMCRCRCER_SPEC

read() method returns mmcrcrcer::R reader structure

Source

impl Readable for MMCRIR_SPEC

read() method returns mmcrir::R reader structure

Source

impl Readable for MMCRSR_SPEC

read() method returns mmcrsr::R reader structure

Source

impl Readable for MMCRUGR_SPEC

read() method returns mmcrugr::R reader structure

Source

impl Readable for MMCTGMCR_SPEC

read() method returns mmctgmcr::R reader structure

Source

impl Readable for MMCTGR_SPEC

read() method returns mmctgr::R reader structure

Source

impl Readable for MMCTGSCR_SPEC

read() method returns mmctgscr::R reader structure

Source

impl Readable for MMCTIR_SPEC

read() method returns mmctir::R reader structure

Source

impl Readable for MMCTSR_SPEC

read() method returns mmctsr::R reader structure

Source

impl Readable for PMTCR_SPEC

read() method returns pmtcr::R reader structure

Source

impl Readable for PMTRWFR_SPEC

read() method returns pmtrwfr::R reader structure

Source

impl Readable for PTPBSAR_SPEC

read() method returns ptpbsar::R reader structure

Source

impl Readable for PTPCR_SPEC

read() method returns ptpcr::R reader structure

Source

impl Readable for PTPNSAR_SPEC

read() method returns ptpnsar::R reader structure

Source

impl Readable for PTPPPSR_SPEC

read() method returns ptpppsr::R reader structure

Source

impl Readable for PTPSBSR_SPEC

read() method returns ptpsbsr::R reader structure

Source

impl Readable for PTPSNSR_SPEC

read() method returns ptpsnsr::R reader structure

Source

impl Readable for PTPSR_SPEC

read() method returns ptpsr::R reader structure

Source

impl Readable for PTPTBSR_SPEC

read() method returns ptptbsr::R reader structure

Source

impl Readable for PTPTNSR_SPEC

read() method returns ptptnsr::R reader structure

Source

impl Readable for PTPUBSR_SPEC

read() method returns ptpubsr::R reader structure

Source

impl Readable for PTPUNSR_SPEC

read() method returns ptpunsr::R reader structure

Source

impl Readable for EMR_SPEC

read() method returns emr::R reader structure

Source

impl Readable for FTSR_SPEC

read() method returns ftsr::R reader structure

Source

impl Readable for mm32f5::exti::imr::IMR_SPEC

read() method returns imr::R reader structure

Source

impl Readable for mm32f5::exti::pr::PR_SPEC

read() method returns pr::R reader structure

Source

impl Readable for RTSR_SPEC

read() method returns rtsr::R reader structure

Source

impl Readable for SWIER_SPEC

read() method returns swier::R reader structure

Source

impl Readable for ACR_SPEC

read() method returns acr::R reader structure

Source

impl Readable for mm32f5::flash::cr::CR_SPEC

read() method returns cr::R reader structure

Source

impl Readable for OBR_SPEC

read() method returns obr::R reader structure

Source

impl Readable for mm32f5::flash::sr::SR_SPEC

read() method returns sr::R reader structure

Source

impl Readable for WRPR0_SPEC

read() method returns wrpr0::R reader structure

Source

impl Readable for WRPR1_SPEC

read() method returns wrpr1::R reader structure

Source

impl Readable for CBT_SPEC

read() method returns cbt::R reader structure

Source

impl Readable for CRCR_SPEC

read() method returns crcr::R reader structure

Source

impl Readable for CS0_SPEC

read() method returns cs0::R reader structure

Source

impl Readable for CTRL1_SPEC

read() method returns ctrl1::R reader structure

Source

impl Readable for CTRL2_SPEC

read() method returns ctrl2::R reader structure

Source

impl Readable for ECR_SPEC

read() method returns ecr::R reader structure

Source

impl Readable for ESR1_SPEC

read() method returns esr1::R reader structure

Source

impl Readable for ESR2_SPEC

read() method returns esr2::R reader structure

Source

impl Readable for ID0_SPEC

read() method returns id0::R reader structure

Source

impl Readable for IFLAG1_SPEC

read() method returns iflag1::R reader structure

Source

impl Readable for IMASK1_SPEC

read() method returns imask1::R reader structure

Source

impl Readable for MCR_SPEC

read() method returns mcr::R reader structure

Source

impl Readable for RX14MASK_SPEC

read() method returns rx14mask::R reader structure

Source

impl Readable for RX15MASK_SPEC

read() method returns rx15mask::R reader structure

Source

impl Readable for RXFGMASK_SPEC

read() method returns rxfgmask::R reader structure

Source

impl Readable for RXFIR_SPEC

read() method returns rxfir::R reader structure

Source

impl Readable for RXIMR0_SPEC

read() method returns rximr0::R reader structure

Source

impl Readable for RXMGMASK_SPEC

read() method returns rxmgmask::R reader structure

Source

impl Readable for TIMER_SPEC

read() method returns timer::R reader structure

Source

impl Readable for WORD0_SPEC

read() method returns word0::R reader structure

Source

impl Readable for WORD1_SPEC

read() method returns word1::R reader structure

Source

impl Readable for SMCTLR_SPEC

read() method returns smctlr::R reader structure

Source

impl Readable for SMSKR0_SPEC

read() method returns smskr0::R reader structure

Source

impl Readable for SMTMGR_SET0_SPEC

read() method returns smtmgr_set0::R reader structure

Source

impl Readable for AFRH_SPEC

read() method returns afrh::R reader structure

Source

impl Readable for AFRL_SPEC

read() method returns afrl::R reader structure

Source

impl Readable for mm32f5::gpioa::crh::CRH_SPEC

read() method returns crh::R reader structure

Source

impl Readable for mm32f5::gpioa::crl::CRL_SPEC

read() method returns crl::R reader structure

Source

impl Readable for mm32f5::gpioa::dcr::DCR_SPEC

read() method returns dcr::R reader structure

Source

impl Readable for mm32f5::gpioa::idr::IDR_SPEC

read() method returns idr::R reader structure

Source

impl Readable for LCKR_SPEC

read() method returns lckr::R reader structure

Source

impl Readable for ODR_SPEC

read() method returns odr::R reader structure

Source

impl Readable for ACTIV_SPEC

read() method returns activ::R reader structure

Source

impl Readable for mm32f5::i2c1::cr::CR_SPEC

read() method returns cr::R reader structure

Source

impl Readable for DMA_SPEC

read() method returns dma::R reader structure

Source

impl Readable for mm32f5::i2c1::dr::DR_SPEC

read() method returns dr::R reader structure

Source

impl Readable for EN_SR_SPEC

read() method returns en_sr::R reader structure

Source

impl Readable for ENR_SPEC

read() method returns enr::R reader structure

Source

impl Readable for FSHR_SPEC

read() method returns fshr::R reader structure

Source

impl Readable for FSLR_SPEC

read() method returns fslr::R reader structure

Source

impl Readable for GC_SPEC

read() method returns gc::R reader structure

Source

impl Readable for mm32f5::i2c1::gcr::GCR_SPEC

read() method returns gcr::R reader structure

Source

impl Readable for HOLD_SPEC

read() method returns hold::R reader structure

Source

impl Readable for ICR_SPEC

read() method returns icr::R reader structure

Source

impl Readable for mm32f5::i2c1::imr::IMR_SPEC

read() method returns imr::R reader structure

Source

impl Readable for mm32f5::i2c1::isr::ISR_SPEC

read() method returns isr::R reader structure

Source

impl Readable for OPT_SAR_SPEC

read() method returns opt_sar::R reader structure

Source

impl Readable for RAWISR_SPEC

read() method returns rawisr::R reader structure

Source

impl Readable for RD_REQ_SPEC

read() method returns rd_req::R reader structure

Source

impl Readable for RX_DONE_SPEC

read() method returns rx_done::R reader structure

Source

impl Readable for RX_OVER_SPEC

read() method returns rx_over::R reader structure

Source

impl Readable for RX_UNDER_SPEC

read() method returns rx_under::R reader structure

Source

impl Readable for RXFLR_SPEC

read() method returns rxflr::R reader structure

Source

impl Readable for RXTLR_SPEC

read() method returns rxtlr::R reader structure

Source

impl Readable for SAR_SPEC

read() method returns sar::R reader structure

Source

impl Readable for SCL_STUCK_SPEC

read() method returns scl_stuck::R reader structure

Source

impl Readable for SCL_TMO_SPEC

read() method returns scl_tmo::R reader structure

Source

impl Readable for SDA_TMO_SPEC

read() method returns sda_tmo::R reader structure

Source

impl Readable for SETUP_SPEC

read() method returns setup::R reader structure

Source

impl Readable for SLV_NACK_SPEC

read() method returns slv_nack::R reader structure

Source

impl Readable for SLVMASK_SPEC

read() method returns slvmask::R reader structure

Source

impl Readable for SLVRCVADDR_SPEC

read() method returns slvrcvaddr::R reader structure

Source

impl Readable for SMB_IDLE_SPEC

read() method returns smb_idle::R reader structure

Source

impl Readable for SMB_IMR_SPEC

read() method returns smb_imr::R reader structure

Source

impl Readable for SMB_ISR_SPEC

read() method returns smb_isr::R reader structure

Source

impl Readable for SMB_MEXT_SPEC

read() method returns smb_mext::R reader structure

Source

impl Readable for SMB_SEXT_SPEC

read() method returns smb_sext::R reader structure

Source

impl Readable for SMB_UDID_LSB_SPEC

read() method returns smb_udid_lsb::R reader structure

Source

impl Readable for SMB_UDID_MSB0_SPEC

read() method returns smb_udid_msb0::R reader structure

Source

impl Readable for SMB_UDID_MSB1_SPEC

read() method returns smb_udid_msb1::R reader structure

Source

impl Readable for SMB_UDID_MSB2_SPEC

read() method returns smb_udid_msb2::R reader structure

Source

impl Readable for SPKLEN_SPEC

read() method returns spklen::R reader structure

Source

impl Readable for mm32f5::i2c1::sr::SR_SPEC

read() method returns sr::R reader structure

Source

impl Readable for SSHR_SPEC

read() method returns sshr::R reader structure

Source

impl Readable for SSLR_SPEC

read() method returns sslr::R reader structure

Source

impl Readable for START_SPEC

read() method returns start::R reader structure

Source

impl Readable for STOP_SPEC

read() method returns stop::R reader structure

Source

impl Readable for TAR_SPEC

read() method returns tar::R reader structure

Source

impl Readable for TX_ABRT_SPEC

read() method returns tx_abrt::R reader structure

Source

impl Readable for TX_ABRT_SRC_SPEC

read() method returns tx_abrt_src::R reader structure

Source

impl Readable for TX_OVER_SPEC

read() method returns tx_over::R reader structure

Source

impl Readable for TXFLR_SPEC

read() method returns txflr::R reader structure

Source

impl Readable for TXTLR_SPEC

read() method returns txtlr::R reader structure

Source

impl Readable for mm32f5::iwdg::cnt::CNT_SPEC

read() method returns cnt::R reader structure

Source

impl Readable for mm32f5::iwdg::cr::CR_SPEC

read() method returns cr::R reader structure

Source

impl Readable for IGEN_SPEC

read() method returns igen::R reader structure

Source

impl Readable for mm32f5::iwdg::pr::PR_SPEC

read() method returns pr::R reader structure

Source

impl Readable for PS_SPEC

read() method returns ps::R reader structure

Source

impl Readable for RLR_SPEC

read() method returns rlr::R reader structure

Source

impl Readable for mm32f5::iwdg::sr::SR_SPEC

read() method returns sr::R reader structure

Source

impl Readable for CFG_SPEC

read() method returns cfg::R reader structure

Source

impl Readable for CMP_SPEC

read() method returns cmp::R reader structure

Source

impl Readable for mm32f5::lpt::cnt::CNT_SPEC

read() method returns cnt::R reader structure

Source

impl Readable for CTRL_SPEC

read() method returns ctrl::R reader structure

Source

impl Readable for IE_SPEC

read() method returns ie::R reader structure

Source

impl Readable for IF_SPEC

read() method returns if_::R reader structure

Source

impl Readable for TARGET_SPEC

read() method returns target::R reader structure

Source

impl Readable for COMPARE_SPEC

read() method returns compare::R reader structure

Source

impl Readable for LPUBAUD_SPEC

read() method returns lpubaud::R reader structure

Source

impl Readable for LPUCON_SPEC

read() method returns lpucon::R reader structure

Source

impl Readable for LPUEN_SPEC

read() method returns lpuen::R reader structure

Source

impl Readable for LPUIF_SPEC

read() method returns lpuif::R reader structure

Source

impl Readable for LPURXD_SPEC

read() method returns lpurxd::R reader structure

Source

impl Readable for LPUSTA_SPEC

read() method returns lpusta::R reader structure

Source

impl Readable for MODU_SPEC

read() method returns modu::R reader structure

Source

impl Readable for WKCKE_SPEC

read() method returns wkcke::R reader structure

Source

impl Readable for CONN1CR_SPEC

read() method returns conn1cr::R reader structure

Source

impl Readable for CONN_CLU1CFG_SPEC

read() method returns conn_clu1cfg::R reader structure

Source

impl Readable for CONN_CLU1SEL_SPEC

read() method returns conn_clu1sel::R reader structure

Source

impl Readable for TRIG1CR_SPEC

read() method returns trig1cr::R reader structure

Source

impl Readable for TRIG_CLU1CFG_SPEC

read() method returns trig_clu1cfg::R reader structure

Source

impl Readable for TRIG_CLU1SEL_SPEC

read() method returns trig_clu1sel::R reader structure

Source

impl Readable for mm32f5::pwr::cfgr::CFGR_SPEC

read() method returns cfgr::R reader structure

Source

impl Readable for mm32f5::pwr::cr1::CR1_SPEC

read() method returns cr1::R reader structure

Source

impl Readable for mm32f5::pwr::cr2::CR2_SPEC

read() method returns cr2::R reader structure

Source

impl Readable for CR3_SPEC

read() method returns cr3::R reader structure

Source

impl Readable for CR4_SPEC

read() method returns cr4::R reader structure

Source

impl Readable for CR5_SPEC

read() method returns cr5::R reader structure

Source

impl Readable for CR6_SPEC

read() method returns cr6::R reader structure

Source

impl Readable for mm32f5::pwr::csr::CSR_SPEC

read() method returns csr::R reader structure

Source

impl Readable for mm32f5::pwr::sr::SR_SPEC

read() method returns sr::R reader structure

Source

impl Readable for mm32f5::qspi::cr::CR_SPEC

read() method returns cr::R reader structure

Source

impl Readable for DABR_SPEC

read() method returns dabr::R reader structure

Source

impl Readable for DMCR_SPEC

read() method returns dmcr::R reader structure

Source

impl Readable for IABR_SPEC

read() method returns iabr::R reader structure

Source

impl Readable for IADR_SPEC

read() method returns iadr::R reader structure

Source

impl Readable for IDER_SPEC

read() method returns ider::R reader structure

Source

impl Readable for IDFR_SPEC

read() method returns idfr::R reader structure

Source

impl Readable for mm32f5::qspi::idlr::IDLR_SPEC

read() method returns idlr::R reader structure

Source

impl Readable for IMCR_SPEC

read() method returns imcr::R reader structure

Source

impl Readable for IWCR_SPEC

read() method returns iwcr::R reader structure

Source

impl Readable for mm32f5::qspi::sr::SR_SPEC

read() method returns sr::R reader structure

Source

impl Readable for ADC1CFGR_SPEC

read() method returns adc1cfgr::R reader structure

Source

impl Readable for ADC2CFGR_SPEC

read() method returns adc2cfgr::R reader structure

Source

impl Readable for AHB1ENR_SPEC

read() method returns ahb1enr::R reader structure

Source

impl Readable for AHB1RSTR_SPEC

read() method returns ahb1rstr::R reader structure

Source

impl Readable for APB1ENR_SPEC

read() method returns apb1enr::R reader structure

Source

impl Readable for APB1RSTR_SPEC

read() method returns apb1rstr::R reader structure

Source

impl Readable for APB2ENR_SPEC

read() method returns apb2enr::R reader structure

Source

impl Readable for APB2RSTR_SPEC

read() method returns apb2rstr::R reader structure

Source

impl Readable for BDCR_SPEC

read() method returns bdcr::R reader structure

Source

impl Readable for mm32f5::rcc::cfgr2::CFGR2_SPEC

read() method returns cfgr2::R reader structure

Source

impl Readable for mm32f5::rcc::cfgr::CFGR_SPEC

read() method returns cfgr::R reader structure

Source

impl Readable for CIR_SPEC

read() method returns cir::R reader structure

Source

impl Readable for mm32f5::rcc::cr::CR_SPEC

read() method returns cr::R reader structure

Source

impl Readable for mm32f5::rcc::csr::CSR_SPEC

read() method returns csr::R reader structure

Source

impl Readable for DACCFGR_SPEC

read() method returns daccfgr::R reader structure

Source

impl Readable for FSMCCFGR_SPEC

read() method returns fsmccfgr::R reader structure

Source

impl Readable for PLL1CFGR_SPEC

read() method returns pll1cfgr::R reader structure

Source

impl Readable for PLL2CFGR_SPEC

read() method returns pll2cfgr::R reader structure

Source

impl Readable for SYSCFG_SPEC

read() method returns syscfg::R reader structure

Source

impl Readable for TPIUCFGR_SPEC

read() method returns tpiucfgr::R reader structure

Source

impl Readable for ALRH_SPEC

read() method returns alrh::R reader structure

Source

impl Readable for ALRL_SPEC

read() method returns alrl::R reader structure

Source

impl Readable for CNTH_SPEC

read() method returns cnth::R reader structure

Source

impl Readable for CNTL_SPEC

read() method returns cntl::R reader structure

Source

impl Readable for mm32f5::rtc::crh::CRH_SPEC

read() method returns crh::R reader structure

Source

impl Readable for mm32f5::rtc::crl::CRL_SPEC

read() method returns crl::R reader structure

Source

impl Readable for DIVH_SPEC

read() method returns divh::R reader structure

Source

impl Readable for DIVL_SPEC

read() method returns divl::R reader structure

Source

impl Readable for LSE_CFG_SPEC

read() method returns lse_cfg::R reader structure

Source

impl Readable for MSRH_SPEC

read() method returns msrh::R reader structure

Source

impl Readable for MSRL_SPEC

read() method returns msrl::R reader structure

Source

impl Readable for I2S_CCTL_SPEC

read() method returns i2s_cctl::R reader structure

Source

impl Readable for I2S_CSTAT_SPEC

read() method returns i2s_cstat::R reader structure

Source

impl Readable for I2S_EXTCTL_SPEC

read() method returns i2s_extctl::R reader structure

Source

impl Readable for I2S_GCTL_SPEC

read() method returns i2s_gctl::R reader structure

Source

impl Readable for I2S_I2SCFGR_SPEC

read() method returns i2s_i2scfgr::R reader structure

Source

impl Readable for I2S_INTEN_SPEC

read() method returns i2s_inten::R reader structure

Source

impl Readable for I2S_INTSTAT_SPEC

read() method returns i2s_intstat::R reader structure

Source

impl Readable for I2S_NSSR_SPEC

read() method returns i2s_nssr::R reader structure

Source

impl Readable for I2S_RXDNR_SPEC

read() method returns i2s_rxdnr::R reader structure

Source

impl Readable for I2S_RXREG_SPEC

read() method returns i2s_rxreg::R reader structure

Source

impl Readable for I2S_SPBRG_SPEC

read() method returns i2s_spbrg::R reader structure

Source

impl Readable for I2S_TXREG_SPEC

read() method returns i2s_txreg::R reader structure

Source

impl Readable for BUS_PRI_SPEC

read() method returns bus_pri::R reader structure

Source

impl Readable for CFGR1_SPEC

read() method returns cfgr1::R reader structure

Source

impl Readable for mm32f5::syscfg::cfgr2::CFGR2_SPEC

read() method returns cfgr2::R reader structure

Source

impl Readable for DMARMP_SPEC

read() method returns dmarmp::R reader structure

Source

impl Readable for EXTICR1_SPEC

read() method returns exticr1::R reader structure

Source

impl Readable for EXTICR2_SPEC

read() method returns exticr2::R reader structure

Source

impl Readable for EXTICR3_SPEC

read() method returns exticr3::R reader structure

Source

impl Readable for EXTICR4_SPEC

read() method returns exticr4::R reader structure

Source

impl Readable for PDETCSR_SPEC

read() method returns pdetcsr::R reader structure

Source

impl Readable for VOSDLY_SPEC

read() method returns vosdly::R reader structure

Source

impl Readable for mm32f5::tim1::arr::ARR_SPEC

read() method returns arr::R reader structure

Source

impl Readable for BDTR_SPEC

read() method returns bdtr::R reader structure

Source

impl Readable for BKINF_SPEC

read() method returns bkinf::R reader structure

Source

impl Readable for mm32f5::tim1::ccer::CCER_SPEC

read() method returns ccer::R reader structure

Source

impl Readable for mm32f5::tim1::ccmr1_input::CCMR1_INPUT_SPEC

read() method returns ccmr1_input::R reader structure

Source

impl Readable for mm32f5::tim1::ccmr1_output::CCMR1_OUTPUT_SPEC

read() method returns ccmr1_output::R reader structure

Source

impl Readable for mm32f5::tim1::ccmr2_input::CCMR2_INPUT_SPEC

read() method returns ccmr2_input::R reader structure

Source

impl Readable for mm32f5::tim1::ccmr2_output::CCMR2_OUTPUT_SPEC

read() method returns ccmr2_output::R reader structure

Source

impl Readable for CCMR3_SPEC

read() method returns ccmr3::R reader structure

Source

impl Readable for mm32f5::tim1::ccr1::CCR1_SPEC

read() method returns ccr1::R reader structure

Source

impl Readable for CCR1FALL_SPEC

read() method returns ccr1fall::R reader structure

Source

impl Readable for CCR5_SPEC

read() method returns ccr5::R reader structure

Source

impl Readable for mm32f5::tim1::cnt::CNT_SPEC

read() method returns cnt::R reader structure

Source

impl Readable for mm32f5::tim1::cr1::CR1_SPEC

read() method returns cr1::R reader structure

Source

impl Readable for mm32f5::tim1::cr2::CR2_SPEC

read() method returns cr2::R reader structure

Source

impl Readable for mm32f5::tim1::dcr::DCR_SPEC

read() method returns dcr::R reader structure

Source

impl Readable for mm32f5::tim1::dier::DIER_SPEC

read() method returns dier::R reader structure

Source

impl Readable for PDER_SPEC

read() method returns pder::R reader structure

Source

impl Readable for mm32f5::tim1::psc::PSC_SPEC

read() method returns psc::R reader structure

Source

impl Readable for RCR_SPEC

read() method returns rcr::R reader structure

Source

impl Readable for mm32f5::tim1::smcr::SMCR_SPEC

read() method returns smcr::R reader structure

Source

impl Readable for mm32f5::tim1::sr::SR_SPEC

read() method returns sr::R reader structure

Source

impl Readable for mm32f5::tim2::arr::ARR_SPEC

read() method returns arr::R reader structure

Source

impl Readable for mm32f5::tim2::ccer::CCER_SPEC

read() method returns ccer::R reader structure

Source

impl Readable for mm32f5::tim2::ccmr1_input::CCMR1_INPUT_SPEC

read() method returns ccmr1_input::R reader structure

Source

impl Readable for mm32f5::tim2::ccmr1_output::CCMR1_OUTPUT_SPEC

read() method returns ccmr1_output::R reader structure

Source

impl Readable for mm32f5::tim2::ccmr2_input::CCMR2_INPUT_SPEC

read() method returns ccmr2_input::R reader structure

Source

impl Readable for mm32f5::tim2::ccmr2_output::CCMR2_OUTPUT_SPEC

read() method returns ccmr2_output::R reader structure

Source

impl Readable for mm32f5::tim2::ccr1::CCR1_SPEC

read() method returns ccr1::R reader structure

Source

impl Readable for mm32f5::tim2::cnt::CNT_SPEC

read() method returns cnt::R reader structure

Source

impl Readable for mm32f5::tim2::cr1::CR1_SPEC

read() method returns cr1::R reader structure

Source

impl Readable for mm32f5::tim2::cr2::CR2_SPEC

read() method returns cr2::R reader structure

Source

impl Readable for mm32f5::tim2::dcr::DCR_SPEC

read() method returns dcr::R reader structure

Source

impl Readable for mm32f5::tim2::dier::DIER_SPEC

read() method returns dier::R reader structure

Source

impl Readable for OR_SPEC

read() method returns or::R reader structure

Source

impl Readable for mm32f5::tim2::psc::PSC_SPEC

read() method returns psc::R reader structure

Source

impl Readable for mm32f5::tim2::smcr::SMCR_SPEC

read() method returns smcr::R reader structure

Source

impl Readable for mm32f5::tim2::sr::SR_SPEC

read() method returns sr::R reader structure

Source

impl Readable for mm32f5::tim3::arr::ARR_SPEC

read() method returns arr::R reader structure

Source

impl Readable for mm32f5::tim3::ccer::CCER_SPEC

read() method returns ccer::R reader structure

Source

impl Readable for mm32f5::tim3::ccmr1_input::CCMR1_INPUT_SPEC

read() method returns ccmr1_input::R reader structure

Source

impl Readable for mm32f5::tim3::ccmr1_output::CCMR1_OUTPUT_SPEC

read() method returns ccmr1_output::R reader structure

Source

impl Readable for mm32f5::tim3::ccmr2_input::CCMR2_INPUT_SPEC

read() method returns ccmr2_input::R reader structure

Source

impl Readable for mm32f5::tim3::ccmr2_output::CCMR2_OUTPUT_SPEC

read() method returns ccmr2_output::R reader structure

Source

impl Readable for mm32f5::tim3::ccr1::CCR1_SPEC

read() method returns ccr1::R reader structure

Source

impl Readable for mm32f5::tim3::cnt::CNT_SPEC

read() method returns cnt::R reader structure

Source

impl Readable for mm32f5::tim3::cr1::CR1_SPEC

read() method returns cr1::R reader structure

Source

impl Readable for mm32f5::tim3::cr2::CR2_SPEC

read() method returns cr2::R reader structure

Source

impl Readable for mm32f5::tim3::dcr::DCR_SPEC

read() method returns dcr::R reader structure

Source

impl Readable for mm32f5::tim3::dier::DIER_SPEC

read() method returns dier::R reader structure

Source

impl Readable for mm32f5::tim3::psc::PSC_SPEC

read() method returns psc::R reader structure

Source

impl Readable for mm32f5::tim3::smcr::SMCR_SPEC

read() method returns smcr::R reader structure

Source

impl Readable for mm32f5::tim3::sr::SR_SPEC

read() method returns sr::R reader structure

Source

impl Readable for mm32f5::tim6::arr::ARR_SPEC

read() method returns arr::R reader structure

Source

impl Readable for mm32f5::tim6::cnt::CNT_SPEC

read() method returns cnt::R reader structure

Source

impl Readable for mm32f5::tim6::cr1::CR1_SPEC

read() method returns cr1::R reader structure

Source

impl Readable for mm32f5::tim6::dier::DIER_SPEC

read() method returns dier::R reader structure

Source

impl Readable for mm32f5::tim6::psc::PSC_SPEC

read() method returns psc::R reader structure

Source

impl Readable for mm32f5::tim6::sr::SR_SPEC

read() method returns sr::R reader structure

Source

impl Readable for ABRCR_SPEC

read() method returns abrcr::R reader structure

Source

impl Readable for BRR_SPEC

read() method returns brr::R reader structure

Source

impl Readable for CCR_SPEC

read() method returns ccr::R reader structure

Source

impl Readable for mm32f5::uart1::csr::CSR_SPEC

read() method returns csr::R reader structure

Source

impl Readable for FRA_SPEC

read() method returns fra::R reader structure

Source

impl Readable for mm32f5::uart1::gcr::GCR_SPEC

read() method returns gcr::R reader structure

Source

impl Readable for mm32f5::uart1::idlr::IDLR_SPEC

read() method returns idlr::R reader structure

Source

impl Readable for IER_SPEC

read() method returns ier::R reader structure

Source

impl Readable for IRDA_SPEC

read() method returns irda::R reader structure

Source

impl Readable for mm32f5::uart1::isr::ISR_SPEC

read() method returns isr::R reader structure

Source

impl Readable for RDR_SPEC

read() method returns rdr::R reader structure

Source

impl Readable for RXADDR_SPEC

read() method returns rxaddr::R reader structure

Source

impl Readable for RXMASK_SPEC

read() method returns rxmask::R reader structure

Source

impl Readable for SCR_SPEC

read() method returns scr::R reader structure

Source

impl Readable for TDR_SPEC

read() method returns tdr::R reader structure

Source

impl Readable for FSADDR_SPEC

read() method returns fsaddr::R reader structure

Source

impl Readable for FSBDT_PAGE_01_SPEC

read() method returns fsbdt_page_01::R reader structure

Source

impl Readable for FSBDT_PAGE_02_SPEC

read() method returns fsbdt_page_02::R reader structure

Source

impl Readable for FSBDT_PAGE_03_SPEC

read() method returns fsbdt_page_03::R reader structure

Source

impl Readable for FSCTL_SPEC

read() method returns fsctl::R reader structure

Source

impl Readable for FSEP0_CTL_SPEC

read() method returns fsep0_ctl::R reader structure

Source

impl Readable for FSERR_ENB_SPEC

read() method returns fserr_enb::R reader structure

Source

impl Readable for FSERR_STAT_SPEC

read() method returns fserr_stat::R reader structure

Source

impl Readable for FSFRM_NUMH_SPEC

read() method returns fsfrm_numh::R reader structure

Source

impl Readable for FSFRM_NUML_SPEC

read() method returns fsfrm_numl::R reader structure

Source

impl Readable for FSINT_ENB_SPEC

read() method returns fsint_enb::R reader structure

Source

impl Readable for FSINT_STAT_SPEC

read() method returns fsint_stat::R reader structure

Source

impl Readable for FSOTG_CTRL_SPEC

read() method returns fsotg_ctrl::R reader structure

Source

impl Readable for FSOTG_ICTRL_SPEC

read() method returns fsotg_ictrl::R reader structure

Source

impl Readable for FSOTG_ISTAT_SPEC

read() method returns fsotg_istat::R reader structure

Source

impl Readable for FSOTG_STAT_SPEC

read() method returns fsotg_stat::R reader structure

Source

impl Readable for FSSOF_THLD_SPEC

read() method returns fssof_thld::R reader structure

Source

impl Readable for FSSTAT_SPEC

read() method returns fsstat::R reader structure

Source

impl Readable for FSTOKEN_SPEC

read() method returns fstoken::R reader structure

Source

impl Readable for FSUSBCTRL_SPEC

read() method returns fsusbctrl::R reader structure

Source

impl Readable for mm32f5::wwdg::cfgr::CFGR_SPEC

read() method returns cfgr::R reader structure

Source

impl Readable for mm32f5::wwdg::cr::CR_SPEC

read() method returns cr::R reader structure

Source

impl Readable for mm32f5::wwdg::sr::SR_SPEC

read() method returns sr::R reader structure