pub trait Readable: RegisterSpec {
type Reader: From<R<Self>> + Deref<Target = R<Self>>;
}Expand description
Trait implemented by readable registers to enable the read method.
Registers marked with Writable can be also be modify’ed.
Required Associated Types
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementors
Sourceimpl Readable for ADCFG2_SPEC
read() method returns adcfg2::R reader structure
impl Readable for ADCFG2_SPEC
read() method returns adcfg2::R reader structure
Sourceimpl Readable for ADCFG_SPEC
read() method returns adcfg::R reader structure
impl Readable for ADCFG_SPEC
read() method returns adcfg::R reader structure
Sourceimpl Readable for ADCHS_SPEC
read() method returns adchs::R reader structure
impl Readable for ADCHS_SPEC
read() method returns adchs::R reader structure
Sourceimpl Readable for ADCMPR_SPEC
read() method returns adcmpr::R reader structure
impl Readable for ADCMPR_SPEC
read() method returns adcmpr::R reader structure
Sourceimpl Readable for ADDATA_SPEC
read() method returns addata::R reader structure
impl Readable for ADDATA_SPEC
read() method returns addata::R reader structure
Sourceimpl Readable for ADDR0_SPEC
read() method returns addr0::R reader structure
impl Readable for ADDR0_SPEC
read() method returns addr0::R reader structure
Sourceimpl Readable for ADSTA_SPEC
read() method returns adsta::R reader structure
impl Readable for ADSTA_SPEC
read() method returns adsta::R reader structure
Sourceimpl Readable for ADSTA_EXT_SPEC
read() method returns adsta_ext::R reader structure
impl Readable for ADSTA_EXT_SPEC
read() method returns adsta_ext::R reader structure
Sourceimpl Readable for ANY_CFG_SPEC
read() method returns any_cfg::R reader structure
impl Readable for ANY_CFG_SPEC
read() method returns any_cfg::R reader structure
Sourceimpl Readable for ANY_CR_SPEC
read() method returns any_cr::R reader structure
impl Readable for ANY_CR_SPEC
read() method returns any_cr::R reader structure
Sourceimpl Readable for CHANY0_SPEC
read() method returns chany0::R reader structure
impl Readable for CHANY0_SPEC
read() method returns chany0::R reader structure
Sourceimpl Readable for CHANY1_SPEC
read() method returns chany1::R reader structure
impl Readable for CHANY1_SPEC
read() method returns chany1::R reader structure
Sourceimpl Readable for JADDATA_SPEC
read() method returns jaddata::R reader structure
impl Readable for JADDATA_SPEC
read() method returns jaddata::R reader structure
Sourceimpl Readable for JOFR0_SPEC
read() method returns jofr0::R reader structure
impl Readable for JOFR0_SPEC
read() method returns jofr0::R reader structure
Sourceimpl Readable for SMPR1_SPEC
read() method returns smpr1::R reader structure
impl Readable for SMPR1_SPEC
read() method returns smpr1::R reader structure
Sourceimpl Readable for SMPR2_SPEC
read() method returns smpr2::R reader structure
impl Readable for SMPR2_SPEC
read() method returns smpr2::R reader structure
Sourceimpl Readable for RTCCR_SPEC
read() method returns rtccr::R reader structure
impl Readable for RTCCR_SPEC
read() method returns rtccr::R reader structure
Sourceimpl Readable for DHR8R1_SPEC
read() method returns dhr8r1::R reader structure
impl Readable for DHR8R1_SPEC
read() method returns dhr8r1::R reader structure
Sourceimpl Readable for DHR8R2_SPEC
read() method returns dhr8r2::R reader structure
impl Readable for DHR8R2_SPEC
read() method returns dhr8r2::R reader structure
Sourceimpl Readable for DHR8RD_SPEC
read() method returns dhr8rd::R reader structure
impl Readable for DHR8RD_SPEC
read() method returns dhr8rd::R reader structure
Sourceimpl Readable for DHR12L1_SPEC
read() method returns dhr12l1::R reader structure
impl Readable for DHR12L1_SPEC
read() method returns dhr12l1::R reader structure
Sourceimpl Readable for DHR12L2_SPEC
read() method returns dhr12l2::R reader structure
impl Readable for DHR12L2_SPEC
read() method returns dhr12l2::R reader structure
Sourceimpl Readable for DHR12LD_SPEC
read() method returns dhr12ld::R reader structure
impl Readable for DHR12LD_SPEC
read() method returns dhr12ld::R reader structure
Sourceimpl Readable for DHR12R1_SPEC
read() method returns dhr12r1::R reader structure
impl Readable for DHR12R1_SPEC
read() method returns dhr12r1::R reader structure
Sourceimpl Readable for DHR12R2_SPEC
read() method returns dhr12r2::R reader structure
impl Readable for DHR12R2_SPEC
read() method returns dhr12r2::R reader structure
Sourceimpl Readable for DHR12RD_SPEC
read() method returns dhr12rd::R reader structure
impl Readable for DHR12RD_SPEC
read() method returns dhr12rd::R reader structure
Sourceimpl Readable for IDCODE_SPEC
read() method returns idcode::R reader structure
impl Readable for IDCODE_SPEC
read() method returns idcode::R reader structure
Sourceimpl Readable for mm32f5::dma1::ccr1::CCR1_SPEC
read() method returns ccr1::R reader structure
impl Readable for mm32f5::dma1::ccr1::CCR1_SPEC
read() method returns ccr1::R reader structure
Sourceimpl Readable for CMAR1_SPEC
read() method returns cmar1::R reader structure
impl Readable for CMAR1_SPEC
read() method returns cmar1::R reader structure
Sourceimpl Readable for CNDTR1_SPEC
read() method returns cndtr1::R reader structure
impl Readable for CNDTR1_SPEC
read() method returns cndtr1::R reader structure
Sourceimpl Readable for CPAR1_SPEC
read() method returns cpar1::R reader structure
impl Readable for CPAR1_SPEC
read() method returns cpar1::R reader structure
Sourceimpl Readable for DMABSR_SPEC
read() method returns dmabsr::R reader structure
impl Readable for DMABSR_SPEC
read() method returns dmabsr::R reader structure
Sourceimpl Readable for DMACURRXBFAR_SPEC
read() method returns dmacurrxbfar::R reader structure
impl Readable for DMACURRXBFAR_SPEC
read() method returns dmacurrxbfar::R reader structure
Sourceimpl Readable for DMACURRXDSAR_SPEC
read() method returns dmacurrxdsar::R reader structure
impl Readable for DMACURRXDSAR_SPEC
read() method returns dmacurrxdsar::R reader structure
Sourceimpl Readable for DMACURTXBFAR_SPEC
read() method returns dmacurtxbfar::R reader structure
impl Readable for DMACURTXBFAR_SPEC
read() method returns dmacurtxbfar::R reader structure
Sourceimpl Readable for DMACURTXDSAR_SPEC
read() method returns dmacurtxdsar::R reader structure
impl Readable for DMACURTXDSAR_SPEC
read() method returns dmacurtxdsar::R reader structure
Sourceimpl Readable for DMAFLCR_SPEC
read() method returns dmaflcr::R reader structure
impl Readable for DMAFLCR_SPEC
read() method returns dmaflcr::R reader structure
Sourceimpl Readable for DMAIR_SPEC
read() method returns dmair::R reader structure
impl Readable for DMAIR_SPEC
read() method returns dmair::R reader structure
Sourceimpl Readable for DMAMDR_SPEC
read() method returns dmamdr::R reader structure
impl Readable for DMAMDR_SPEC
read() method returns dmamdr::R reader structure
Sourceimpl Readable for DMARXDSAR_SPEC
read() method returns dmarxdsar::R reader structure
impl Readable for DMARXDSAR_SPEC
read() method returns dmarxdsar::R reader structure
Sourceimpl Readable for DMARXPDR_SPEC
read() method returns dmarxpdr::R reader structure
impl Readable for DMARXPDR_SPEC
read() method returns dmarxpdr::R reader structure
Sourceimpl Readable for DMASR_SPEC
read() method returns dmasr::R reader structure
impl Readable for DMASR_SPEC
read() method returns dmasr::R reader structure
Sourceimpl Readable for DMATXDSAR_SPEC
read() method returns dmatxdsar::R reader structure
impl Readable for DMATXDSAR_SPEC
read() method returns dmatxdsar::R reader structure
Sourceimpl Readable for DMATXPDR_SPEC
read() method returns dmatxpdr::R reader structure
impl Readable for DMATXPDR_SPEC
read() method returns dmatxpdr::R reader structure
Sourceimpl Readable for DMAWDTR_SPEC
read() method returns dmawdtr::R reader structure
impl Readable for DMAWDTR_SPEC
read() method returns dmawdtr::R reader structure
Sourceimpl Readable for MACAFR_SPEC
read() method returns macafr::R reader structure
impl Readable for MACAFR_SPEC
read() method returns macafr::R reader structure
Sourceimpl Readable for MACAHR0_SPEC
read() method returns macahr0::R reader structure
impl Readable for MACAHR0_SPEC
read() method returns macahr0::R reader structure
Sourceimpl Readable for MACALR0_SPEC
read() method returns macalr0::R reader structure
impl Readable for MACALR0_SPEC
read() method returns macalr0::R reader structure
Sourceimpl Readable for MACCR_SPEC
read() method returns maccr::R reader structure
impl Readable for MACCR_SPEC
read() method returns maccr::R reader structure
Sourceimpl Readable for MACFCR_SPEC
read() method returns macfcr::R reader structure
impl Readable for MACFCR_SPEC
read() method returns macfcr::R reader structure
Sourceimpl Readable for MACHTHR_SPEC
read() method returns machthr::R reader structure
impl Readable for MACHTHR_SPEC
read() method returns machthr::R reader structure
Sourceimpl Readable for MACHTLR_SPEC
read() method returns machtlr::R reader structure
impl Readable for MACHTLR_SPEC
read() method returns machtlr::R reader structure
Sourceimpl Readable for MACIMR_SPEC
read() method returns macimr::R reader structure
impl Readable for MACIMR_SPEC
read() method returns macimr::R reader structure
Sourceimpl Readable for MACISR_SPEC
read() method returns macisr::R reader structure
impl Readable for MACISR_SPEC
read() method returns macisr::R reader structure
Sourceimpl Readable for MACSMIAR_SPEC
read() method returns macsmiar::R reader structure
impl Readable for MACSMIAR_SPEC
read() method returns macsmiar::R reader structure
Sourceimpl Readable for MACSMIDR_SPEC
read() method returns macsmidr::R reader structure
impl Readable for MACSMIDR_SPEC
read() method returns macsmidr::R reader structure
Sourceimpl Readable for MACSR_SPEC
read() method returns macsr::R reader structure
impl Readable for MACSR_SPEC
read() method returns macsr::R reader structure
Sourceimpl Readable for MACVLHTR_SPEC
read() method returns macvlhtr::R reader structure
impl Readable for MACVLHTR_SPEC
read() method returns macvlhtr::R reader structure
Sourceimpl Readable for MACVLTRR_SPEC
read() method returns macvltrr::R reader structure
impl Readable for MACVLTRR_SPEC
read() method returns macvltrr::R reader structure
Sourceimpl Readable for MACVLTTR_SPEC
read() method returns macvlttr::R reader structure
impl Readable for MACVLTTR_SPEC
read() method returns macvlttr::R reader structure
Sourceimpl Readable for MMCCR_SPEC
read() method returns mmccr::R reader structure
impl Readable for MMCCR_SPEC
read() method returns mmccr::R reader structure
Sourceimpl Readable for MMCRALIER_SPEC
read() method returns mmcralier::R reader structure
impl Readable for MMCRALIER_SPEC
read() method returns mmcralier::R reader structure
Sourceimpl Readable for MMCRCRCER_SPEC
read() method returns mmcrcrcer::R reader structure
impl Readable for MMCRCRCER_SPEC
read() method returns mmcrcrcer::R reader structure
Sourceimpl Readable for MMCRIR_SPEC
read() method returns mmcrir::R reader structure
impl Readable for MMCRIR_SPEC
read() method returns mmcrir::R reader structure
Sourceimpl Readable for MMCRSR_SPEC
read() method returns mmcrsr::R reader structure
impl Readable for MMCRSR_SPEC
read() method returns mmcrsr::R reader structure
Sourceimpl Readable for MMCRUGR_SPEC
read() method returns mmcrugr::R reader structure
impl Readable for MMCRUGR_SPEC
read() method returns mmcrugr::R reader structure
Sourceimpl Readable for MMCTGMCR_SPEC
read() method returns mmctgmcr::R reader structure
impl Readable for MMCTGMCR_SPEC
read() method returns mmctgmcr::R reader structure
Sourceimpl Readable for MMCTGR_SPEC
read() method returns mmctgr::R reader structure
impl Readable for MMCTGR_SPEC
read() method returns mmctgr::R reader structure
Sourceimpl Readable for MMCTGSCR_SPEC
read() method returns mmctgscr::R reader structure
impl Readable for MMCTGSCR_SPEC
read() method returns mmctgscr::R reader structure
Sourceimpl Readable for MMCTIR_SPEC
read() method returns mmctir::R reader structure
impl Readable for MMCTIR_SPEC
read() method returns mmctir::R reader structure
Sourceimpl Readable for MMCTSR_SPEC
read() method returns mmctsr::R reader structure
impl Readable for MMCTSR_SPEC
read() method returns mmctsr::R reader structure
Sourceimpl Readable for PMTCR_SPEC
read() method returns pmtcr::R reader structure
impl Readable for PMTCR_SPEC
read() method returns pmtcr::R reader structure
Sourceimpl Readable for PMTRWFR_SPEC
read() method returns pmtrwfr::R reader structure
impl Readable for PMTRWFR_SPEC
read() method returns pmtrwfr::R reader structure
Sourceimpl Readable for PTPBSAR_SPEC
read() method returns ptpbsar::R reader structure
impl Readable for PTPBSAR_SPEC
read() method returns ptpbsar::R reader structure
Sourceimpl Readable for PTPCR_SPEC
read() method returns ptpcr::R reader structure
impl Readable for PTPCR_SPEC
read() method returns ptpcr::R reader structure
Sourceimpl Readable for PTPNSAR_SPEC
read() method returns ptpnsar::R reader structure
impl Readable for PTPNSAR_SPEC
read() method returns ptpnsar::R reader structure
Sourceimpl Readable for PTPPPSR_SPEC
read() method returns ptpppsr::R reader structure
impl Readable for PTPPPSR_SPEC
read() method returns ptpppsr::R reader structure
Sourceimpl Readable for PTPSBSR_SPEC
read() method returns ptpsbsr::R reader structure
impl Readable for PTPSBSR_SPEC
read() method returns ptpsbsr::R reader structure
Sourceimpl Readable for PTPSNSR_SPEC
read() method returns ptpsnsr::R reader structure
impl Readable for PTPSNSR_SPEC
read() method returns ptpsnsr::R reader structure
Sourceimpl Readable for PTPSR_SPEC
read() method returns ptpsr::R reader structure
impl Readable for PTPSR_SPEC
read() method returns ptpsr::R reader structure
Sourceimpl Readable for PTPTBSR_SPEC
read() method returns ptptbsr::R reader structure
impl Readable for PTPTBSR_SPEC
read() method returns ptptbsr::R reader structure
Sourceimpl Readable for PTPTNSR_SPEC
read() method returns ptptnsr::R reader structure
impl Readable for PTPTNSR_SPEC
read() method returns ptptnsr::R reader structure
Sourceimpl Readable for PTPUBSR_SPEC
read() method returns ptpubsr::R reader structure
impl Readable for PTPUBSR_SPEC
read() method returns ptpubsr::R reader structure
Sourceimpl Readable for PTPUNSR_SPEC
read() method returns ptpunsr::R reader structure
impl Readable for PTPUNSR_SPEC
read() method returns ptpunsr::R reader structure
Sourceimpl Readable for SWIER_SPEC
read() method returns swier::R reader structure
impl Readable for SWIER_SPEC
read() method returns swier::R reader structure
Sourceimpl Readable for WRPR0_SPEC
read() method returns wrpr0::R reader structure
impl Readable for WRPR0_SPEC
read() method returns wrpr0::R reader structure
Sourceimpl Readable for WRPR1_SPEC
read() method returns wrpr1::R reader structure
impl Readable for WRPR1_SPEC
read() method returns wrpr1::R reader structure
Sourceimpl Readable for CTRL1_SPEC
read() method returns ctrl1::R reader structure
impl Readable for CTRL1_SPEC
read() method returns ctrl1::R reader structure
Sourceimpl Readable for CTRL2_SPEC
read() method returns ctrl2::R reader structure
impl Readable for CTRL2_SPEC
read() method returns ctrl2::R reader structure
Sourceimpl Readable for IFLAG1_SPEC
read() method returns iflag1::R reader structure
impl Readable for IFLAG1_SPEC
read() method returns iflag1::R reader structure
Sourceimpl Readable for IMASK1_SPEC
read() method returns imask1::R reader structure
impl Readable for IMASK1_SPEC
read() method returns imask1::R reader structure
Sourceimpl Readable for RX14MASK_SPEC
read() method returns rx14mask::R reader structure
impl Readable for RX14MASK_SPEC
read() method returns rx14mask::R reader structure
Sourceimpl Readable for RX15MASK_SPEC
read() method returns rx15mask::R reader structure
impl Readable for RX15MASK_SPEC
read() method returns rx15mask::R reader structure
Sourceimpl Readable for RXFGMASK_SPEC
read() method returns rxfgmask::R reader structure
impl Readable for RXFGMASK_SPEC
read() method returns rxfgmask::R reader structure
Sourceimpl Readable for RXFIR_SPEC
read() method returns rxfir::R reader structure
impl Readable for RXFIR_SPEC
read() method returns rxfir::R reader structure
Sourceimpl Readable for RXIMR0_SPEC
read() method returns rximr0::R reader structure
impl Readable for RXIMR0_SPEC
read() method returns rximr0::R reader structure
Sourceimpl Readable for RXMGMASK_SPEC
read() method returns rxmgmask::R reader structure
impl Readable for RXMGMASK_SPEC
read() method returns rxmgmask::R reader structure
Sourceimpl Readable for TIMER_SPEC
read() method returns timer::R reader structure
impl Readable for TIMER_SPEC
read() method returns timer::R reader structure
Sourceimpl Readable for WORD0_SPEC
read() method returns word0::R reader structure
impl Readable for WORD0_SPEC
read() method returns word0::R reader structure
Sourceimpl Readable for WORD1_SPEC
read() method returns word1::R reader structure
impl Readable for WORD1_SPEC
read() method returns word1::R reader structure
Sourceimpl Readable for SMCTLR_SPEC
read() method returns smctlr::R reader structure
impl Readable for SMCTLR_SPEC
read() method returns smctlr::R reader structure
Sourceimpl Readable for SMSKR0_SPEC
read() method returns smskr0::R reader structure
impl Readable for SMSKR0_SPEC
read() method returns smskr0::R reader structure
Sourceimpl Readable for SMTMGR_SET0_SPEC
read() method returns smtmgr_set0::R reader structure
impl Readable for SMTMGR_SET0_SPEC
read() method returns smtmgr_set0::R reader structure
Sourceimpl Readable for ACTIV_SPEC
read() method returns activ::R reader structure
impl Readable for ACTIV_SPEC
read() method returns activ::R reader structure
Sourceimpl Readable for EN_SR_SPEC
read() method returns en_sr::R reader structure
impl Readable for EN_SR_SPEC
read() method returns en_sr::R reader structure
Sourceimpl Readable for OPT_SAR_SPEC
read() method returns opt_sar::R reader structure
impl Readable for OPT_SAR_SPEC
read() method returns opt_sar::R reader structure
Sourceimpl Readable for RAWISR_SPEC
read() method returns rawisr::R reader structure
impl Readable for RAWISR_SPEC
read() method returns rawisr::R reader structure
Sourceimpl Readable for RD_REQ_SPEC
read() method returns rd_req::R reader structure
impl Readable for RD_REQ_SPEC
read() method returns rd_req::R reader structure
Sourceimpl Readable for RX_DONE_SPEC
read() method returns rx_done::R reader structure
impl Readable for RX_DONE_SPEC
read() method returns rx_done::R reader structure
Sourceimpl Readable for RX_OVER_SPEC
read() method returns rx_over::R reader structure
impl Readable for RX_OVER_SPEC
read() method returns rx_over::R reader structure
Sourceimpl Readable for RX_UNDER_SPEC
read() method returns rx_under::R reader structure
impl Readable for RX_UNDER_SPEC
read() method returns rx_under::R reader structure
Sourceimpl Readable for RXFLR_SPEC
read() method returns rxflr::R reader structure
impl Readable for RXFLR_SPEC
read() method returns rxflr::R reader structure
Sourceimpl Readable for RXTLR_SPEC
read() method returns rxtlr::R reader structure
impl Readable for RXTLR_SPEC
read() method returns rxtlr::R reader structure
Sourceimpl Readable for SCL_STUCK_SPEC
read() method returns scl_stuck::R reader structure
impl Readable for SCL_STUCK_SPEC
read() method returns scl_stuck::R reader structure
Sourceimpl Readable for SCL_TMO_SPEC
read() method returns scl_tmo::R reader structure
impl Readable for SCL_TMO_SPEC
read() method returns scl_tmo::R reader structure
Sourceimpl Readable for SDA_TMO_SPEC
read() method returns sda_tmo::R reader structure
impl Readable for SDA_TMO_SPEC
read() method returns sda_tmo::R reader structure
Sourceimpl Readable for SETUP_SPEC
read() method returns setup::R reader structure
impl Readable for SETUP_SPEC
read() method returns setup::R reader structure
Sourceimpl Readable for SLV_NACK_SPEC
read() method returns slv_nack::R reader structure
impl Readable for SLV_NACK_SPEC
read() method returns slv_nack::R reader structure
Sourceimpl Readable for SLVMASK_SPEC
read() method returns slvmask::R reader structure
impl Readable for SLVMASK_SPEC
read() method returns slvmask::R reader structure
Sourceimpl Readable for SLVRCVADDR_SPEC
read() method returns slvrcvaddr::R reader structure
impl Readable for SLVRCVADDR_SPEC
read() method returns slvrcvaddr::R reader structure
Sourceimpl Readable for SMB_IDLE_SPEC
read() method returns smb_idle::R reader structure
impl Readable for SMB_IDLE_SPEC
read() method returns smb_idle::R reader structure
Sourceimpl Readable for SMB_IMR_SPEC
read() method returns smb_imr::R reader structure
impl Readable for SMB_IMR_SPEC
read() method returns smb_imr::R reader structure
Sourceimpl Readable for SMB_ISR_SPEC
read() method returns smb_isr::R reader structure
impl Readable for SMB_ISR_SPEC
read() method returns smb_isr::R reader structure
Sourceimpl Readable for SMB_MEXT_SPEC
read() method returns smb_mext::R reader structure
impl Readable for SMB_MEXT_SPEC
read() method returns smb_mext::R reader structure
Sourceimpl Readable for SMB_SEXT_SPEC
read() method returns smb_sext::R reader structure
impl Readable for SMB_SEXT_SPEC
read() method returns smb_sext::R reader structure
Sourceimpl Readable for SMB_UDID_LSB_SPEC
read() method returns smb_udid_lsb::R reader structure
impl Readable for SMB_UDID_LSB_SPEC
read() method returns smb_udid_lsb::R reader structure
Sourceimpl Readable for SMB_UDID_MSB0_SPEC
read() method returns smb_udid_msb0::R reader structure
impl Readable for SMB_UDID_MSB0_SPEC
read() method returns smb_udid_msb0::R reader structure
Sourceimpl Readable for SMB_UDID_MSB1_SPEC
read() method returns smb_udid_msb1::R reader structure
impl Readable for SMB_UDID_MSB1_SPEC
read() method returns smb_udid_msb1::R reader structure
Sourceimpl Readable for SMB_UDID_MSB2_SPEC
read() method returns smb_udid_msb2::R reader structure
impl Readable for SMB_UDID_MSB2_SPEC
read() method returns smb_udid_msb2::R reader structure
Sourceimpl Readable for SPKLEN_SPEC
read() method returns spklen::R reader structure
impl Readable for SPKLEN_SPEC
read() method returns spklen::R reader structure
Sourceimpl Readable for START_SPEC
read() method returns start::R reader structure
impl Readable for START_SPEC
read() method returns start::R reader structure
Sourceimpl Readable for TX_ABRT_SPEC
read() method returns tx_abrt::R reader structure
impl Readable for TX_ABRT_SPEC
read() method returns tx_abrt::R reader structure
Sourceimpl Readable for TX_ABRT_SRC_SPEC
read() method returns tx_abrt_src::R reader structure
impl Readable for TX_ABRT_SRC_SPEC
read() method returns tx_abrt_src::R reader structure
Sourceimpl Readable for TX_OVER_SPEC
read() method returns tx_over::R reader structure
impl Readable for TX_OVER_SPEC
read() method returns tx_over::R reader structure
Sourceimpl Readable for TXFLR_SPEC
read() method returns txflr::R reader structure
impl Readable for TXFLR_SPEC
read() method returns txflr::R reader structure
Sourceimpl Readable for TXTLR_SPEC
read() method returns txtlr::R reader structure
impl Readable for TXTLR_SPEC
read() method returns txtlr::R reader structure
Sourceimpl Readable for TARGET_SPEC
read() method returns target::R reader structure
impl Readable for TARGET_SPEC
read() method returns target::R reader structure
Sourceimpl Readable for COMPARE_SPEC
read() method returns compare::R reader structure
impl Readable for COMPARE_SPEC
read() method returns compare::R reader structure
Sourceimpl Readable for LPUBAUD_SPEC
read() method returns lpubaud::R reader structure
impl Readable for LPUBAUD_SPEC
read() method returns lpubaud::R reader structure
Sourceimpl Readable for LPUCON_SPEC
read() method returns lpucon::R reader structure
impl Readable for LPUCON_SPEC
read() method returns lpucon::R reader structure
Sourceimpl Readable for LPUEN_SPEC
read() method returns lpuen::R reader structure
impl Readable for LPUEN_SPEC
read() method returns lpuen::R reader structure
Sourceimpl Readable for LPUIF_SPEC
read() method returns lpuif::R reader structure
impl Readable for LPUIF_SPEC
read() method returns lpuif::R reader structure
Sourceimpl Readable for LPURXD_SPEC
read() method returns lpurxd::R reader structure
impl Readable for LPURXD_SPEC
read() method returns lpurxd::R reader structure
Sourceimpl Readable for LPUSTA_SPEC
read() method returns lpusta::R reader structure
impl Readable for LPUSTA_SPEC
read() method returns lpusta::R reader structure
Sourceimpl Readable for WKCKE_SPEC
read() method returns wkcke::R reader structure
impl Readable for WKCKE_SPEC
read() method returns wkcke::R reader structure
Sourceimpl Readable for CONN1CR_SPEC
read() method returns conn1cr::R reader structure
impl Readable for CONN1CR_SPEC
read() method returns conn1cr::R reader structure
Sourceimpl Readable for CONN_CLU1CFG_SPEC
read() method returns conn_clu1cfg::R reader structure
impl Readable for CONN_CLU1CFG_SPEC
read() method returns conn_clu1cfg::R reader structure
Sourceimpl Readable for CONN_CLU1SEL_SPEC
read() method returns conn_clu1sel::R reader structure
impl Readable for CONN_CLU1SEL_SPEC
read() method returns conn_clu1sel::R reader structure
Sourceimpl Readable for TRIG1CR_SPEC
read() method returns trig1cr::R reader structure
impl Readable for TRIG1CR_SPEC
read() method returns trig1cr::R reader structure
Sourceimpl Readable for TRIG_CLU1CFG_SPEC
read() method returns trig_clu1cfg::R reader structure
impl Readable for TRIG_CLU1CFG_SPEC
read() method returns trig_clu1cfg::R reader structure
Sourceimpl Readable for TRIG_CLU1SEL_SPEC
read() method returns trig_clu1sel::R reader structure
impl Readable for TRIG_CLU1SEL_SPEC
read() method returns trig_clu1sel::R reader structure
Sourceimpl Readable for mm32f5::qspi::idlr::IDLR_SPEC
read() method returns idlr::R reader structure
impl Readable for mm32f5::qspi::idlr::IDLR_SPEC
read() method returns idlr::R reader structure
Sourceimpl Readable for ADC1CFGR_SPEC
read() method returns adc1cfgr::R reader structure
impl Readable for ADC1CFGR_SPEC
read() method returns adc1cfgr::R reader structure
Sourceimpl Readable for ADC2CFGR_SPEC
read() method returns adc2cfgr::R reader structure
impl Readable for ADC2CFGR_SPEC
read() method returns adc2cfgr::R reader structure
Sourceimpl Readable for AHB1ENR_SPEC
read() method returns ahb1enr::R reader structure
impl Readable for AHB1ENR_SPEC
read() method returns ahb1enr::R reader structure
Sourceimpl Readable for AHB1RSTR_SPEC
read() method returns ahb1rstr::R reader structure
impl Readable for AHB1RSTR_SPEC
read() method returns ahb1rstr::R reader structure
Sourceimpl Readable for APB1ENR_SPEC
read() method returns apb1enr::R reader structure
impl Readable for APB1ENR_SPEC
read() method returns apb1enr::R reader structure
Sourceimpl Readable for APB1RSTR_SPEC
read() method returns apb1rstr::R reader structure
impl Readable for APB1RSTR_SPEC
read() method returns apb1rstr::R reader structure
Sourceimpl Readable for APB2ENR_SPEC
read() method returns apb2enr::R reader structure
impl Readable for APB2ENR_SPEC
read() method returns apb2enr::R reader structure
Sourceimpl Readable for APB2RSTR_SPEC
read() method returns apb2rstr::R reader structure
impl Readable for APB2RSTR_SPEC
read() method returns apb2rstr::R reader structure
Sourceimpl Readable for mm32f5::rcc::cfgr2::CFGR2_SPEC
read() method returns cfgr2::R reader structure
impl Readable for mm32f5::rcc::cfgr2::CFGR2_SPEC
read() method returns cfgr2::R reader structure
Sourceimpl Readable for DACCFGR_SPEC
read() method returns daccfgr::R reader structure
impl Readable for DACCFGR_SPEC
read() method returns daccfgr::R reader structure
Sourceimpl Readable for FSMCCFGR_SPEC
read() method returns fsmccfgr::R reader structure
impl Readable for FSMCCFGR_SPEC
read() method returns fsmccfgr::R reader structure
Sourceimpl Readable for PLL1CFGR_SPEC
read() method returns pll1cfgr::R reader structure
impl Readable for PLL1CFGR_SPEC
read() method returns pll1cfgr::R reader structure
Sourceimpl Readable for PLL2CFGR_SPEC
read() method returns pll2cfgr::R reader structure
impl Readable for PLL2CFGR_SPEC
read() method returns pll2cfgr::R reader structure
Sourceimpl Readable for SYSCFG_SPEC
read() method returns syscfg::R reader structure
impl Readable for SYSCFG_SPEC
read() method returns syscfg::R reader structure
Sourceimpl Readable for TPIUCFGR_SPEC
read() method returns tpiucfgr::R reader structure
impl Readable for TPIUCFGR_SPEC
read() method returns tpiucfgr::R reader structure
Sourceimpl Readable for LSE_CFG_SPEC
read() method returns lse_cfg::R reader structure
impl Readable for LSE_CFG_SPEC
read() method returns lse_cfg::R reader structure
Sourceimpl Readable for I2S_CCTL_SPEC
read() method returns i2s_cctl::R reader structure
impl Readable for I2S_CCTL_SPEC
read() method returns i2s_cctl::R reader structure
Sourceimpl Readable for I2S_CSTAT_SPEC
read() method returns i2s_cstat::R reader structure
impl Readable for I2S_CSTAT_SPEC
read() method returns i2s_cstat::R reader structure
Sourceimpl Readable for I2S_EXTCTL_SPEC
read() method returns i2s_extctl::R reader structure
impl Readable for I2S_EXTCTL_SPEC
read() method returns i2s_extctl::R reader structure
Sourceimpl Readable for I2S_GCTL_SPEC
read() method returns i2s_gctl::R reader structure
impl Readable for I2S_GCTL_SPEC
read() method returns i2s_gctl::R reader structure
Sourceimpl Readable for I2S_I2SCFGR_SPEC
read() method returns i2s_i2scfgr::R reader structure
impl Readable for I2S_I2SCFGR_SPEC
read() method returns i2s_i2scfgr::R reader structure
Sourceimpl Readable for I2S_INTEN_SPEC
read() method returns i2s_inten::R reader structure
impl Readable for I2S_INTEN_SPEC
read() method returns i2s_inten::R reader structure
Sourceimpl Readable for I2S_INTSTAT_SPEC
read() method returns i2s_intstat::R reader structure
impl Readable for I2S_INTSTAT_SPEC
read() method returns i2s_intstat::R reader structure
Sourceimpl Readable for I2S_NSSR_SPEC
read() method returns i2s_nssr::R reader structure
impl Readable for I2S_NSSR_SPEC
read() method returns i2s_nssr::R reader structure
Sourceimpl Readable for I2S_RXDNR_SPEC
read() method returns i2s_rxdnr::R reader structure
impl Readable for I2S_RXDNR_SPEC
read() method returns i2s_rxdnr::R reader structure
Sourceimpl Readable for I2S_RXREG_SPEC
read() method returns i2s_rxreg::R reader structure
impl Readable for I2S_RXREG_SPEC
read() method returns i2s_rxreg::R reader structure
Sourceimpl Readable for I2S_SPBRG_SPEC
read() method returns i2s_spbrg::R reader structure
impl Readable for I2S_SPBRG_SPEC
read() method returns i2s_spbrg::R reader structure
Sourceimpl Readable for I2S_TXREG_SPEC
read() method returns i2s_txreg::R reader structure
impl Readable for I2S_TXREG_SPEC
read() method returns i2s_txreg::R reader structure
Sourceimpl Readable for BUS_PRI_SPEC
read() method returns bus_pri::R reader structure
impl Readable for BUS_PRI_SPEC
read() method returns bus_pri::R reader structure
Sourceimpl Readable for CFGR1_SPEC
read() method returns cfgr1::R reader structure
impl Readable for CFGR1_SPEC
read() method returns cfgr1::R reader structure
Sourceimpl Readable for mm32f5::syscfg::cfgr2::CFGR2_SPEC
read() method returns cfgr2::R reader structure
impl Readable for mm32f5::syscfg::cfgr2::CFGR2_SPEC
read() method returns cfgr2::R reader structure
Sourceimpl Readable for DMARMP_SPEC
read() method returns dmarmp::R reader structure
impl Readable for DMARMP_SPEC
read() method returns dmarmp::R reader structure
Sourceimpl Readable for EXTICR1_SPEC
read() method returns exticr1::R reader structure
impl Readable for EXTICR1_SPEC
read() method returns exticr1::R reader structure
Sourceimpl Readable for EXTICR2_SPEC
read() method returns exticr2::R reader structure
impl Readable for EXTICR2_SPEC
read() method returns exticr2::R reader structure
Sourceimpl Readable for EXTICR3_SPEC
read() method returns exticr3::R reader structure
impl Readable for EXTICR3_SPEC
read() method returns exticr3::R reader structure
Sourceimpl Readable for EXTICR4_SPEC
read() method returns exticr4::R reader structure
impl Readable for EXTICR4_SPEC
read() method returns exticr4::R reader structure
Sourceimpl Readable for PDETCSR_SPEC
read() method returns pdetcsr::R reader structure
impl Readable for PDETCSR_SPEC
read() method returns pdetcsr::R reader structure
Sourceimpl Readable for VOSDLY_SPEC
read() method returns vosdly::R reader structure
impl Readable for VOSDLY_SPEC
read() method returns vosdly::R reader structure
Sourceimpl Readable for BKINF_SPEC
read() method returns bkinf::R reader structure
impl Readable for BKINF_SPEC
read() method returns bkinf::R reader structure
Sourceimpl Readable for mm32f5::tim1::ccer::CCER_SPEC
read() method returns ccer::R reader structure
impl Readable for mm32f5::tim1::ccer::CCER_SPEC
read() method returns ccer::R reader structure
Sourceimpl Readable for mm32f5::tim1::ccmr1_input::CCMR1_INPUT_SPEC
read() method returns ccmr1_input::R reader structure
impl Readable for mm32f5::tim1::ccmr1_input::CCMR1_INPUT_SPEC
read() method returns ccmr1_input::R reader structure
Sourceimpl Readable for mm32f5::tim1::ccmr1_output::CCMR1_OUTPUT_SPEC
read() method returns ccmr1_output::R reader structure
impl Readable for mm32f5::tim1::ccmr1_output::CCMR1_OUTPUT_SPEC
read() method returns ccmr1_output::R reader structure
Sourceimpl Readable for mm32f5::tim1::ccmr2_input::CCMR2_INPUT_SPEC
read() method returns ccmr2_input::R reader structure
impl Readable for mm32f5::tim1::ccmr2_input::CCMR2_INPUT_SPEC
read() method returns ccmr2_input::R reader structure
Sourceimpl Readable for mm32f5::tim1::ccmr2_output::CCMR2_OUTPUT_SPEC
read() method returns ccmr2_output::R reader structure
impl Readable for mm32f5::tim1::ccmr2_output::CCMR2_OUTPUT_SPEC
read() method returns ccmr2_output::R reader structure
Sourceimpl Readable for CCMR3_SPEC
read() method returns ccmr3::R reader structure
impl Readable for CCMR3_SPEC
read() method returns ccmr3::R reader structure
Sourceimpl Readable for mm32f5::tim1::ccr1::CCR1_SPEC
read() method returns ccr1::R reader structure
impl Readable for mm32f5::tim1::ccr1::CCR1_SPEC
read() method returns ccr1::R reader structure
Sourceimpl Readable for CCR1FALL_SPEC
read() method returns ccr1fall::R reader structure
impl Readable for CCR1FALL_SPEC
read() method returns ccr1fall::R reader structure
Sourceimpl Readable for mm32f5::tim1::dier::DIER_SPEC
read() method returns dier::R reader structure
impl Readable for mm32f5::tim1::dier::DIER_SPEC
read() method returns dier::R reader structure
Sourceimpl Readable for mm32f5::tim1::smcr::SMCR_SPEC
read() method returns smcr::R reader structure
impl Readable for mm32f5::tim1::smcr::SMCR_SPEC
read() method returns smcr::R reader structure
Sourceimpl Readable for mm32f5::tim2::ccer::CCER_SPEC
read() method returns ccer::R reader structure
impl Readable for mm32f5::tim2::ccer::CCER_SPEC
read() method returns ccer::R reader structure
Sourceimpl Readable for mm32f5::tim2::ccmr1_input::CCMR1_INPUT_SPEC
read() method returns ccmr1_input::R reader structure
impl Readable for mm32f5::tim2::ccmr1_input::CCMR1_INPUT_SPEC
read() method returns ccmr1_input::R reader structure
Sourceimpl Readable for mm32f5::tim2::ccmr1_output::CCMR1_OUTPUT_SPEC
read() method returns ccmr1_output::R reader structure
impl Readable for mm32f5::tim2::ccmr1_output::CCMR1_OUTPUT_SPEC
read() method returns ccmr1_output::R reader structure
Sourceimpl Readable for mm32f5::tim2::ccmr2_input::CCMR2_INPUT_SPEC
read() method returns ccmr2_input::R reader structure
impl Readable for mm32f5::tim2::ccmr2_input::CCMR2_INPUT_SPEC
read() method returns ccmr2_input::R reader structure
Sourceimpl Readable for mm32f5::tim2::ccmr2_output::CCMR2_OUTPUT_SPEC
read() method returns ccmr2_output::R reader structure
impl Readable for mm32f5::tim2::ccmr2_output::CCMR2_OUTPUT_SPEC
read() method returns ccmr2_output::R reader structure
Sourceimpl Readable for mm32f5::tim2::ccr1::CCR1_SPEC
read() method returns ccr1::R reader structure
impl Readable for mm32f5::tim2::ccr1::CCR1_SPEC
read() method returns ccr1::R reader structure
Sourceimpl Readable for mm32f5::tim2::dier::DIER_SPEC
read() method returns dier::R reader structure
impl Readable for mm32f5::tim2::dier::DIER_SPEC
read() method returns dier::R reader structure
Sourceimpl Readable for mm32f5::tim2::smcr::SMCR_SPEC
read() method returns smcr::R reader structure
impl Readable for mm32f5::tim2::smcr::SMCR_SPEC
read() method returns smcr::R reader structure
Sourceimpl Readable for mm32f5::tim3::ccer::CCER_SPEC
read() method returns ccer::R reader structure
impl Readable for mm32f5::tim3::ccer::CCER_SPEC
read() method returns ccer::R reader structure
Sourceimpl Readable for mm32f5::tim3::ccmr1_input::CCMR1_INPUT_SPEC
read() method returns ccmr1_input::R reader structure
impl Readable for mm32f5::tim3::ccmr1_input::CCMR1_INPUT_SPEC
read() method returns ccmr1_input::R reader structure
Sourceimpl Readable for mm32f5::tim3::ccmr1_output::CCMR1_OUTPUT_SPEC
read() method returns ccmr1_output::R reader structure
impl Readable for mm32f5::tim3::ccmr1_output::CCMR1_OUTPUT_SPEC
read() method returns ccmr1_output::R reader structure
Sourceimpl Readable for mm32f5::tim3::ccmr2_input::CCMR2_INPUT_SPEC
read() method returns ccmr2_input::R reader structure
impl Readable for mm32f5::tim3::ccmr2_input::CCMR2_INPUT_SPEC
read() method returns ccmr2_input::R reader structure
Sourceimpl Readable for mm32f5::tim3::ccmr2_output::CCMR2_OUTPUT_SPEC
read() method returns ccmr2_output::R reader structure
impl Readable for mm32f5::tim3::ccmr2_output::CCMR2_OUTPUT_SPEC
read() method returns ccmr2_output::R reader structure
Sourceimpl Readable for mm32f5::tim3::ccr1::CCR1_SPEC
read() method returns ccr1::R reader structure
impl Readable for mm32f5::tim3::ccr1::CCR1_SPEC
read() method returns ccr1::R reader structure
Sourceimpl Readable for mm32f5::tim3::dier::DIER_SPEC
read() method returns dier::R reader structure
impl Readable for mm32f5::tim3::dier::DIER_SPEC
read() method returns dier::R reader structure
Sourceimpl Readable for mm32f5::tim3::smcr::SMCR_SPEC
read() method returns smcr::R reader structure
impl Readable for mm32f5::tim3::smcr::SMCR_SPEC
read() method returns smcr::R reader structure
Sourceimpl Readable for mm32f5::tim6::dier::DIER_SPEC
read() method returns dier::R reader structure
impl Readable for mm32f5::tim6::dier::DIER_SPEC
read() method returns dier::R reader structure
Sourceimpl Readable for ABRCR_SPEC
read() method returns abrcr::R reader structure
impl Readable for ABRCR_SPEC
read() method returns abrcr::R reader structure
Sourceimpl Readable for mm32f5::uart1::idlr::IDLR_SPEC
read() method returns idlr::R reader structure
impl Readable for mm32f5::uart1::idlr::IDLR_SPEC
read() method returns idlr::R reader structure
Sourceimpl Readable for RXADDR_SPEC
read() method returns rxaddr::R reader structure
impl Readable for RXADDR_SPEC
read() method returns rxaddr::R reader structure
Sourceimpl Readable for RXMASK_SPEC
read() method returns rxmask::R reader structure
impl Readable for RXMASK_SPEC
read() method returns rxmask::R reader structure
Sourceimpl Readable for FSADDR_SPEC
read() method returns fsaddr::R reader structure
impl Readable for FSADDR_SPEC
read() method returns fsaddr::R reader structure
Sourceimpl Readable for FSBDT_PAGE_01_SPEC
read() method returns fsbdt_page_01::R reader structure
impl Readable for FSBDT_PAGE_01_SPEC
read() method returns fsbdt_page_01::R reader structure
Sourceimpl Readable for FSBDT_PAGE_02_SPEC
read() method returns fsbdt_page_02::R reader structure
impl Readable for FSBDT_PAGE_02_SPEC
read() method returns fsbdt_page_02::R reader structure
Sourceimpl Readable for FSBDT_PAGE_03_SPEC
read() method returns fsbdt_page_03::R reader structure
impl Readable for FSBDT_PAGE_03_SPEC
read() method returns fsbdt_page_03::R reader structure
Sourceimpl Readable for FSCTL_SPEC
read() method returns fsctl::R reader structure
impl Readable for FSCTL_SPEC
read() method returns fsctl::R reader structure
Sourceimpl Readable for FSEP0_CTL_SPEC
read() method returns fsep0_ctl::R reader structure
impl Readable for FSEP0_CTL_SPEC
read() method returns fsep0_ctl::R reader structure
Sourceimpl Readable for FSERR_ENB_SPEC
read() method returns fserr_enb::R reader structure
impl Readable for FSERR_ENB_SPEC
read() method returns fserr_enb::R reader structure
Sourceimpl Readable for FSERR_STAT_SPEC
read() method returns fserr_stat::R reader structure
impl Readable for FSERR_STAT_SPEC
read() method returns fserr_stat::R reader structure
Sourceimpl Readable for FSFRM_NUMH_SPEC
read() method returns fsfrm_numh::R reader structure
impl Readable for FSFRM_NUMH_SPEC
read() method returns fsfrm_numh::R reader structure
Sourceimpl Readable for FSFRM_NUML_SPEC
read() method returns fsfrm_numl::R reader structure
impl Readable for FSFRM_NUML_SPEC
read() method returns fsfrm_numl::R reader structure
Sourceimpl Readable for FSINT_ENB_SPEC
read() method returns fsint_enb::R reader structure
impl Readable for FSINT_ENB_SPEC
read() method returns fsint_enb::R reader structure
Sourceimpl Readable for FSINT_STAT_SPEC
read() method returns fsint_stat::R reader structure
impl Readable for FSINT_STAT_SPEC
read() method returns fsint_stat::R reader structure
Sourceimpl Readable for FSOTG_CTRL_SPEC
read() method returns fsotg_ctrl::R reader structure
impl Readable for FSOTG_CTRL_SPEC
read() method returns fsotg_ctrl::R reader structure
Sourceimpl Readable for FSOTG_ICTRL_SPEC
read() method returns fsotg_ictrl::R reader structure
impl Readable for FSOTG_ICTRL_SPEC
read() method returns fsotg_ictrl::R reader structure
Sourceimpl Readable for FSOTG_ISTAT_SPEC
read() method returns fsotg_istat::R reader structure
impl Readable for FSOTG_ISTAT_SPEC
read() method returns fsotg_istat::R reader structure
Sourceimpl Readable for FSOTG_STAT_SPEC
read() method returns fsotg_stat::R reader structure
impl Readable for FSOTG_STAT_SPEC
read() method returns fsotg_stat::R reader structure
Sourceimpl Readable for FSSOF_THLD_SPEC
read() method returns fssof_thld::R reader structure
impl Readable for FSSOF_THLD_SPEC
read() method returns fssof_thld::R reader structure
Sourceimpl Readable for FSSTAT_SPEC
read() method returns fsstat::R reader structure
impl Readable for FSSTAT_SPEC
read() method returns fsstat::R reader structure
Sourceimpl Readable for FSTOKEN_SPEC
read() method returns fstoken::R reader structure
impl Readable for FSTOKEN_SPEC
read() method returns fstoken::R reader structure
Sourceimpl Readable for FSUSBCTRL_SPEC
read() method returns fsusbctrl::R reader structure
impl Readable for FSUSBCTRL_SPEC
read() method returns fsusbctrl::R reader structure
Sourceimpl Readable for mm32f5::wwdg::cfgr::CFGR_SPEC
read() method returns cfgr::R reader structure
impl Readable for mm32f5::wwdg::cfgr::CFGR_SPEC
read() method returns cfgr::R reader structure